@@ -2,24 +2,34 @@
 main application classes and widgets for GUIApp-conform Kivy apps
 =================================================================
 
-This ae portion is providing some useful constants, various enhanced widget classes, two application classes
-(:class:`FrameworkApp` and :class:`KivyMainApp`) and a i18n wrapper (:func:`get_txt`) adding translatable f-strings to
-the python and kv code of your app.
+This ae portion is providing additional :ref:`config-variables` and some useful constants, various enhanced widget
+classes, two application classes (:class:`FrameworkApp` and :class:`KivyMainApp`) and a i18n wrapper (:func:`get_txt`),
+adding translatable f-strings to the python and kv code of your app.
 
 
-kivy app constants
-------------------
+kivy app constants and config variables
+---------------------------------------
 
-More information on each constants you find in the constant declaration section starting with :data:`MAIN_KV_FILE_NAME`.
+With the optional :ref:`config-variables` `win_min_width` and `win_min_height`, added by this portion, you can restrict
+the minimum size of the kivy main window of your app. Their default values are set on app startup in the method
+:meth:`~KivyMainApp.on_app_start`.
+
+More constants provided by this portion are in the constant declaration section starting with :data:`MAIN_KV_FILE_NAME`.
+
+Additionally, all the :ref:`config-variables` and app constants inherited from the base app classes are available.
+
+.. hint::
+    Please see the documentation of the namespace portions/modules :mod:`ae.console` and :mod:`ae.gui_app` for more
+    detailed information on all the inherited :ref:`config-variables`, :ref:`config-options`, :ref:`config-files` and
+    :ref:`app-state-constants`.
 
 
 enhanced widget classes
 -----------------------
 
 The widgets provided by this portion are based on the kivy widgets and are respecting the :ref:`app-state-variables`
-specifying the desired app style (dark or light) and font size.
-
-Most of them also change automatically the :ref:`application flow`.
+specifying the desired app style (dark or light) and font size. Most of them also change automatically the
+:ref:`application flow`.
 
 The following widgets provided by this portion will be registered in the kivy widget class maps by importing this module
 to be available for your app:
@@ -37,20 +47,19 @@ to be available for your app:
 * :class:`OptionalButton`: dynamic kivy widget based on :class:`FlowButton` which can be dynamically hidden.
 * :class:`UserNameEditorPopup`: popup window used e.g. to enter new user, finally registered in the app config files.
 
+
 kivy app classes
 ----------------
 
-The class :class:`KivyMainApp` is implementing a main app class that is reducing the amount of code needed for
-to create a Python application based on the `kivy framework <https://kivy.org>`_.
+The class :class:`KivyMainApp` is implementing a main app class that is reducing the amount of code needed to create
+a Python application based on the `kivy framework <https://kivy.org>`_.
 
 :class:`KivyMainApp` is based on the following classes:
 
-* the abstract base class :class:`~ae.gui_app.MainAppBase` which adds the concepts of :ref:`application status`
-  (including :ref:`app-state-variables` and :ref:`app-state-constants`), :ref:`application flow` and
-  :ref:`application events`.
-* the class :class:`~ae.console.ConsoleApp` is adding :ref:`config-files`, :ref:`config-variables`
-  and :ref:`config-options`.
-* the class :class:`~ae.core.AppBase` is adding :ref:`application logging` and :ref:`application debugging`.
+* the abstract base class :class:`~ae.gui_app.MainAppBase` which adds :ref:`application status`,
+  :ref:`app-state-variables` and :ref:`app-state-constants`), :ref:`application flow` and :ref:`application events`.
+* :class:`~ae.console.ConsoleApp` is adding :ref:`config-files`, :ref:`config-variables` and :ref:`config-options`.
+* :class:`~ae.core.AppBase` is adding :ref:`application logging` and :ref:`application debugging`.
 
 This namespace portion is also encapsulating the :class:`Kivy App class <kivy.app.App>` within the :class:`FrameworkApp`
 class. This Kivy app class instance can be directly accessed from the main app class instance via the
@@ -61,9 +70,8 @@ kivy application events
 ^^^^^^^^^^^^^^^^^^^^^^^
 
 This portion is firing :ref:`application events` additional to the ones provided by :class:`~ae.gui_app.MainAppBase` by
-redirecting events of the Kivy :class:`~kivy.app.App` class (the original Kivy event/callback-method name is
-given in brackets). These framework app events get fired after :meth:`~ae.gui_app.MainAppBase.on_app_run` got executed
-and in the following order:
+redirecting events of Kivy's :class:`~kivy.app.App` class (the Kivy event/callback-method name is given in brackets).
+These framework app events get fired after :meth:`~ae.gui_app.MainAppBase.on_app_run` in the following order:
 
 * on_app_build (kivy.app.App.build, after the main kv file get loaded).
 * on_app_built (kivy.app.App.build, after the root widget get build).
@@ -87,7 +95,6 @@ unit tests need at least V 2.0 of OpenGL and the kivy framework installed.
 .. note::
     unit tests does have 100 % coverage but are currently not passing the gitlab CI tests because we failing in setup
     a proper running window system on the python image that all ae portions are using.
-
 """
 import os
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
@@ -103,7 +110,7 @@ from kivy.core.window import Window
 from kivy.factory import Factory, FactoryException                                          # type: ignore
 from kivy.input import MotionEvent                                                          # type: ignore
 from kivy.lang import Builder, Observable, global_idmap                                     # type: ignore
-from kivy.metrics import sp                                                                 # type: ignore
+from kivy.metrics import dp, sp                                                             # type: ignore
 # pylint: disable=no-name-in-module
 from kivy.properties import (                                                               # type: ignore
     BooleanProperty, ColorProperty, DictProperty, ListProperty, NumericProperty, ObjectProperty, StringProperty)
@@ -119,7 +126,7 @@ import kivy.uix.textinput
 from kivy.uix.textinput import TextInput, TextInputCutCopyPaste as _TextInputCutCopyPaste   # type: ignore
 from kivy.uix.widget import Widget                                                          # type: ignore
 
-from ae.base import norm_name, os_platform                                                  # type: ignore
+from ae.base import os_platform                                                             # type: ignore
 from ae.files import CachedFile                                                             # type: ignore
 from ae.paths import app_docs_path                                                          # type: ignore
 from ae.i18n import default_language, get_f_string                                          # type: ignore
@@ -127,7 +134,7 @@ from ae.core import DEBUG_LEVELS, DEBUG_LEVEL_ENABLED
 
 # id_of_flow not used here - added for easier import in app project
 from ae.gui_app import (                                                                    # type: ignore
-    APP_STATE_SECTION_NAME, USER_NAME_MAX_LEN,
+    APP_STATE_SECTION_NAME, MAX_FONT_SIZE, MIN_FONT_SIZE,
     THEME_LIGHT_BACKGROUND_COLOR, THEME_LIGHT_FONT_COLOR, THEME_DARK_BACKGROUND_COLOR, THEME_DARK_FONT_COLOR,
     ensure_tap_kwargs_refs, id_of_flow, replace_flow_action
 )
@@ -139,7 +146,7 @@ from ae.kivy_help import HelpBehavior, HelpToggler, ModalBehavior, Tooltip, Tour
 from ae.kivy_relief_canvas import relief_colors, ReliefCanvas                               # type: ignore
 
 
-__version__ = '0.1.88'
+__version__ = '0.2.94'
 
 
 MAIN_KV_FILE_NAME = 'main.kv'  #: default file name of the main kv file
@@ -151,17 +158,19 @@ ANI_SINE_DEEPER_REPEAT3 = \
 """ sine 3 x deeper repeating animation, used e.g. to animate help layout (ae.kivy_help.Tooltip) """
 ANI_SINE_DEEPER_REPEAT3.repeat = True
 
-LOVE_VIBRATE_PATTERN = (0.0, 0.12, 0.12, 0.21, 0.03, 0.12, 0.12, 0.12)
-""" short/~1.2s vibrate pattern for fun/love notification. """
-
-ERROR_VIBRATE_PATTERN = (0.0, 0.09, 0.09, 0.18, 0.18, 0.27, 0.18, 0.36, 0.27, 0.45)
-""" long/~2s vibrate pattern for error notification. """
-
 CRITICAL_VIBRATE_PATTERN = (0.00, 0.12, 0.12, 0.12, 0.12, 0.12,
                             0.12, 0.24, 0.12, 0.24, 0.12, 0.24,
                             0.12, 0.12, 0.12, 0.12, 0.12, 0.12)
 """ very long/~2.4s vibrate pattern for critical error notification (sending SOS to the mobile world;) """
 
+ERROR_VIBRATE_PATTERN = (0.0, 0.09, 0.09, 0.18, 0.18, 0.27, 0.18, 0.36, 0.27, 0.45)
+""" long/~2s vibrate pattern for error notification. """
+
+LOVE_VIBRATE_PATTERN = (0.0, 0.12, 0.12, 0.21, 0.03, 0.12, 0.12, 0.12)
+""" short/~1.2s vibrate pattern for fun/love notification. """
+
+TOUCH_VIBRATE_PATTERN = (0.0, 0.09, 0.09, 0.06, 0.03, 0.03)
+""" very short/~0.3s vibrate pattern for button and toggler touch. """
 
 # load/declare base widgets with integrated app flow and observers ensuring change of app states (e.g. theme and size)
 Builder.load_file(os.path.join(os.path.dirname(__file__), "widgets.kv"))
@@ -218,6 +227,9 @@ class ImageButton(ButtonBehavior, ImageLabel):  # pragma: no cover
             # pylint: disable=maybe-no-member
             touch.ud['long_touch_handler'] = long_touch_handler = lambda dt: self.dispatch('on_long_tap', touch)
             Clock.schedule_once(long_touch_handler, 0.99)
+            main_app = App.get_running_app().main_app
+            main_app.play_vibrate(TOUCH_VIBRATE_PATTERN)
+            main_app.play_sound('touched')
         return super().on_touch_down(touch)  # does touch.grab(self)
 
     @staticmethod
@@ -414,6 +426,8 @@ class FlowInput(HelpBehavior, TextInput, ShadersMixin):  # pragma: no cover
 
         super().__init__(**kwargs)
 
+        self.main_app = App.get_running_app().main_app
+
         if not FlowInput._ac_dropdown:
             FlowInput._ac_dropdown = FlowDropDown()  # widget instances cannot be created in class var declaration
 
@@ -487,6 +501,11 @@ class FlowInput(HelpBehavior, TextInput, ShadersMixin):  # pragma: no cover
 
         return super().keyboard_on_key_down(window, keycode, text, modifiers)
 
+    def keyboard_on_textinput(self, window, text):
+        """ overridden to suppress any user input if tour is running/active. """
+        if not self.main_app.tour_layout:
+            super().keyboard_on_textinput(window, text)
+
     def on_focus(self, _self, focus: bool):
         """ change flow on text input change of focus.
 
@@ -497,7 +516,7 @@ class FlowInput(HelpBehavior, TextInput, ShadersMixin):  # pragma: no cover
             flow_id = self.focus_flow_id or id_of_flow('edit')
         else:
             flow_id = self.unfocus_flow_id or id_of_flow('close')
-        App.get_running_app().main_app.change_flow(flow_id)
+        self.main_app.change_flow(flow_id)
 
     def on_text(self, _self, text: str):
         """ TextInput.text change event handler.
@@ -518,7 +537,7 @@ class FlowInput(HelpBehavior, TextInput, ShadersMixin):  # pragma: no cover
                 cdm.append(dict(cls='FlowButton', kwargs=dict(text=txt, on_release=self._select_ac_text)))
             self._ac_dropdown.child_data_maps[:] = cdm
             if not self._ac_dropdown.attach_to:
-                App.get_running_app().main_app.change_flow(replace_flow_action(self.focus_flow_id, 'suggest'))
+                self.main_app.change_flow(replace_flow_action(self.focus_flow_id, 'suggest'))
                 self._ac_dropdown.open(self)
             self._change_selector_index(0)
             # suggestion_text will be removed in Kivy 2.1.0 - see PR #7437
@@ -630,7 +649,7 @@ class FlowPopup(ModalBehavior, DynamicChildrenBehavior, ReliefCanvas, BoxLayout)
     """
 
     query_data_maps: List[Dict[str, Any]] = ListProperty()
-    """ list of child data dicts for to instantiate the query widgets (most likely :class:`FlowButton`) of this popup.
+    """ list of child data dicts to instantiate the query widgets (most likely :class:`FlowButton`) of this popup.
 
     :attr:`query_data_maps` is a :class:`~kivy.properties.ListProperty` and defaults to an empty list.
     """
@@ -700,7 +719,7 @@ class FlowPopup(ModalBehavior, DynamicChildrenBehavior, ReliefCanvas, BoxLayout)
 
         .. note:: prevents close/dismiss of any dropdown/popup while clicking on help activator widget.
 
-        :param _args:           arguments (for to have compatible signature for DropDown/Popup/ModalView widgets).
+        :param _args:           arguments (to have compatible signature for DropDown/Popup/ModalView widgets).
         :param kwargs:          keyword arguments (compatible signature for DropDown/Popup/ModalView widgets).
         """
         if self._window is None:
@@ -749,7 +768,7 @@ class FlowPopup(ModalBehavior, DynamicChildrenBehavior, ReliefCanvas, BoxLayout)
     def open(self, *_args, **kwargs):
         """ start optional open animation after calling open method if exists in inheriting container/layout widget.
 
-        :param _args:           unused argument (for to have compatible signature for Popup/ModalView and DropDown
+        :param _args:           unused argument (to have compatible signature for Popup/ModalView and DropDown
                                 widgets passing the parent widget).
         :param kwargs:          extra arguments that are removed before to be passed to the inheriting open method:
 
@@ -795,6 +814,9 @@ class FlowToggler(HelpBehavior, ToggleButtonBehavior, ImageLabel):  # pragma: no
             self._touch_x, self._touch_y = touch.pos
             # pylint: disable=no-member # suppress center_x/y false positives
             Animation(_touch_anim=1.0, _touch_x=self.center_x, _touch_y=self.center_y, t='out_quad', d=0.39).start(self)
+            main_app = App.get_running_app().main_app
+            main_app.play_vibrate(TOUCH_VIBRATE_PATTERN)
+            main_app.play_sound('touched')
         return super().on_touch_down(touch)
 
 
@@ -802,26 +824,24 @@ class FrameworkApp(App):
     """ kivy framework app class proxy redirecting events and callbacks to the main app class instance. """
 
     app_states = DictProperty()                         #: duplicate of MainAppBase app state for events/binds
-    displayed_help_id = StringProperty()                #: help id of the currently explained/help-target widget
-    help_layout = ObjectProperty(allownone=True)        #: layout widget if help mode is active else None
-    tour_layout = ObjectProperty(allownone=True)        #: overlay layout widget if tour is active else None
-
     button_height = NumericProperty('45sp')             #: default button height, dynamically calculated from font size
+    displayed_help_id = StringProperty()                #: help id of the currently explained/help-target widget
     font_color = ObjectProperty(THEME_DARK_FONT_COLOR)  #: rgba color of the font used for labels/buttons/...
+    help_layout = ObjectProperty(allownone=True)        #: layout widget if help mode is active else None
     landscape = BooleanProperty()                       #: True if app win width is bigger than the app win height
+    max_font_size = NumericProperty(MAX_FONT_SIZE)      #: maximum font size in pixels bound to window size
+    min_font_size = NumericProperty(MIN_FONT_SIZE)      #: minimum - " -
     mixed_back_ink = ListProperty((.69, .69, .69, 1.))  #: background color mixed from available back inks
+    tour_layout = ObjectProperty(allownone=True)        #: overlay layout widget if tour is active else None
 
     def __init__(self, main_app: 'KivyMainApp', **kwargs):
         """ init kivy app """
-        self.main_app = main_app                        #: set reference to KivyMainApp instance
-        self.title = main_app.app_title                 #: set kivy.app.App.title
-        self.icon = os.path.join("img", "app_icon.png")  #: set kivy.app.App.icon
+        self.main_app = main_app                            #: set reference to KivyMainApp instance
+        self.title = main_app.app_title                     #: set kivy.app.App.title
+        self.icon = os.path.join("img", "app_icon.png")     #: set kivy.app.App.icon
 
         super().__init__(**kwargs)
 
-        self.bind(app_states=lambda *args: setattr(self, 'button_height', round(self.main_app.font_size * 1.5))
-                  if self.button_height != round(self.main_app.font_size * 1.5) else None)
-
     def build(self) -> Widget:
         """ kivy build app callback.
 
@@ -836,6 +856,12 @@ class FrameworkApp(App):
                     on_key_down=self.key_press_from_kivy,
                     on_key_up=self.key_release_from_kivy)
 
+        def _set_button_height(*_args):
+            new_height = round(self.main_app.font_size * 1.5)
+            if self.button_height != new_height:
+                self.button_height = new_height
+        self.bind(app_states=_set_button_height)
+
         self.main_app.framework_root = root = Factory.Main()
         self.main_app.call_method('on_app_built')
         return root
@@ -917,7 +943,8 @@ class FrameworkApp(App):
 
 class MessageShowPopup(FlowPopup):
     """ flow popup to display info or error messages. """
-    message = StringProperty()  #: popup window label text (message to display)
+    message = StringProperty()  #: popup window message text to display
+    title = StringProperty()    #: popup window title text to display
 
 
 class _GetTextBinder(Observable):
@@ -1086,7 +1113,8 @@ class KivyMainApp(HelpAppBase):
     def call_method_delayed(self, delay: float, callback: Union[Callable, str], *args, **kwargs) -> Any:
         """ delayed call of passed callable/method with args/kwargs catching and logging exceptions preventing app exit.
 
-        :param delay:           delay in seconds when to call the callable/method specified by :paramref:`.callback`.
+        :param delay:           delay in seconds before calling the callable/method specified by
+                                :paramref:`~call_method_delayed.callback`.
         :param callback:        either callable or name of the main app method to call.
         :param args:            args passed to the callable/main-app-method to be called.
         :param kwargs:          kwargs passed to the callable/main-app-method to be called.
@@ -1113,17 +1141,25 @@ class KivyMainApp(HelpAppBase):
 
     @staticmethod
     def dpi_factor() -> float:
-        """ dpi scaling factor - overwrite if the used GUI framework supports dpi scaling. """
-        return sp(1.0)
+        """ dpi scaling factor - overridden to use Kivy's dpi scaling. """
+        return dp(1.0)
 
     def ensure_top_most_z_index(self, widget: Widget):
-        """ ensure visibility of the passed widget to be the top most in the z index/order
+        """ ensure visibility of the passed widget to be the top most in the z index/order.
 
         :param widget:          widget to check and possibly correct to be the top most one.
+
+        if other dropdown/popup opened after the passed widget/layout, then only correct z index/order to show this
+        widget/layout in front (as top-most widget). if the passed widget has a method named `activate_modal` (like e.g.
+        :meth:`ae.kivy_help.ModalBehavior.activate_modal`) then its `activate_modal` method will be called instead.
         """
-        if self.framework_win.children[0] != widget:  # if other dropdown/popup opened after help layout
-            self.framework_win.remove_widget(widget)  # then correct z index/order to show help text in front
-            self.framework_win.add_widget(widget)
+        if self.framework_win.children[0] != widget:
+            reactivate_modal = getattr(widget, 'activate_modal', None)
+            if callable(reactivate_modal):
+                reactivate_modal()
+            else:
+                self.framework_win.remove_widget(widget)
+                self.framework_win.add_widget(widget)
 
     def help_activation_toggle(self):  # pragma: no cover
         """ button tapped event handler to switch help mode between active and inactive (also inactivating tour). """
@@ -1164,14 +1200,16 @@ class KivyMainApp(HelpAppBase):
         super().load_sounds()  # load from sound file paths all files into :class:`~ae.files.RegisteredFile` instances
         self.sound_files.reclassify(object_loader=lambda f: SoundLoader.load(f.path))  # :class:`~ae.files.CachedFile`
 
+    def on_app_build(self):
+        """ kivy App build event handler called at the begin of :meth:`kivy.app.App.build`. """
+        super().on_app_build()
+        self.vpo("KivyMainApp.on_app_build - reload image resources from kv file late imports, e.g. ae.kivy_user_prefs")
+        self.load_images()
+
     def on_app_built(self):
         """ kivy App build event handler called at the end of :meth:`kivy.app.App.build`. """
         self.vpo("KivyMainApp.on_app_built default/fallback event handler called")
 
-    def on_app_init(self):
-        """ setup loaded app states within the now available framework app and its widgets. """
-        self.vpo("KivyMainApp.on_app_built default/fallback event handler called")
-
     def on_app_pause(self):
         """ kivy :meth:`~kivy.app.App.on_pause` event handler. """
         self.vpo("KivyMainApp.on_app_pause default/fallback event handler called")
@@ -1181,11 +1219,15 @@ class KivyMainApp(HelpAppBase):
         self.vpo("KivyMainApp.on_app_resume default/fallback event handler called")
 
     def on_app_start(self):  # pragma: no cover
-        """ app start event handler - used to set the window pos and size. """
+        """ app start event handler - used to set the user preference app states and initial window pos and size. """
         super().on_app_start()
+        self.vpo("KivyMainApp.on_app_start - setting lang, theme, win-pos/-size and softinput mode")
+
         get_txt.switch_lang(self.lang_code)
         self.change_light_theme(self.light_theme)
         Window.softinput_mode = self.kbd_input_mode
+        Window.minimum_width = self.get_var('win_min_width', default_value=405)
+        Window.minimum_height = self.get_var('win_min_height', default_value=303)
 
         if os_platform not in ('android', 'ios'):  # ignore last win pos on android/iOS, use always the full screen
             win_rect = self.win_rectangle
@@ -1233,45 +1275,6 @@ class KivyMainApp(HelpAppBase):
         self.vpo(f"KivyMainApp.on_light_theme: theme got changed to {self.light_theme}")
         self.change_light_theme(self.light_theme)
 
-    def on_user_add(self, user_id: str, event_kwargs: Dict[str, Any]) -> bool:
-        """ enable debug mode after clicking 3 times within 6 seconds.
-
-        :param user_id:         new user id.
-        :param event_kwargs:    optionally pass True in the `unique_user_name` key to prevent duplicate user names.
-        :return:                True if user got registered else False.
-        """
-        if not user_id:
-            self.show_message(get_txt("please enter your user or nick name"))
-            return False
-        if len(user_id) > USER_NAME_MAX_LEN:
-            self.show_message(get_txt("please shorten your user name to not more than {USER_NAME_MAX_LEN} characters",
-                                      glo_vars=globals()))
-            return False
-
-        chk_id = norm_name(user_id)
-        if user_id != chk_id:
-            self.show_message(get_txt("please remove spaces and the characters "
-                                      "'{''.join(ch for ch in user_id if ch not in chk_id)}' from your user name",
-                                      glo_vars=locals().copy()))
-            return False
-
-        user_data = dict()
-        if user_id in self.registered_users:
-            if event_kwargs.get('unique_user_name', False) and \
-                    any(usr for usr in self.registered_users.values() if usr.get('user_name') == user_id):
-                self.show_message(get_txt("user name {user_id} already exists", glo_vars=locals().copy()))
-                return False
-
-            user_data['user_name'] = user_id
-            idx = 1
-            while True:
-                user_id = f'usr_id_{idx}'
-                if user_id not in self.registered_users:
-                    break
-                idx += 1
-
-        return self.register_user(user_id, **user_data)
-
     def on_user_preferences_open(self, _flow_id: str, _event_kwargs: Dict[str, Any]) -> bool:
         """ enable debug mode after clicking 3 times within 6 seconds.
 
@@ -1312,7 +1315,7 @@ class KivyMainApp(HelpAppBase):
         else:
             self.dpo(f"KivyMainApp.play_sound({sound_name}) not found")
 
-    def play_vibrate(self, pattern: Tuple = (0.03, 0.3)):
+    def play_vibrate(self, pattern: Tuple = ERROR_VIBRATE_PATTERN):
         """ play vibrate pattern. """
         self.vpo(f"KivyMainApp.play_vibrate {pattern}")
         if self.framework_app.app_states.get('vibration_volume', 1.):  # no volume available, at least disable if 0.0
@@ -1327,7 +1330,7 @@ class KivyMainApp(HelpAppBase):
         """ determine all popup-like container widgets that are currently opened.
 
         :param classes:         optional class filter - if not passed then only the widgets underneath win/root with an
-                                `open` method will be yielded. Pass tuple for to restrict found popup widgets to certain
+                                `open` method will be yielded. Pass tuple to restrict found popup widgets to certain
                                 classes. like e.g. by passing `(Popup, DropDown, FlowPopup)` to get all popups of an
                                 ae/Kivy app.
         :return:                list of opened/visible popup class instances that are children of either the
@@ -1336,23 +1339,6 @@ class KivyMainApp(HelpAppBase):
         """
         return list(reversed(super().popups_opened(classes=classes)))
 
-    def show_message(self, message: str, title: str = "", is_error: bool = True):
-        """ display (error) message popup to the user.
-
-        :param message:         message string to display.
-        :param title:           title of message box.
-        :param is_error:        pass False to not emit error tone/vibration.
-        """
-        if is_error:
-            self.play_vibrate(ERROR_VIBRATE_PATTERN)
-            self.play_beep()
-
-        popup_kwargs = dict(message=message)
-        if title:
-            popup_kwargs['title'] = title
-
-        self.change_flow(id_of_flow('show', 'message'), popup_kwargs=popup_kwargs)
-
     def open_popup(self, popup_class: Type[Union[FlowPopup, Popup, DropDown]], **popup_kwargs) -> Widget:
         """ open Popup or DropDown using the `open` method. Overwriting the main app class method.
 
@@ -1372,21 +1358,23 @@ class KivyMainApp(HelpAppBase):
 
         return popup_instance
 
-    def text_size_guess(self, text: str, font_size: float = 0.0) -> Tuple[float, float]:
+    def text_size_guess(self, text: str, font_size: float = 0.0, padding: Tuple[float, float] = (0.0, 0.0)
+                        ) -> Tuple[float, float]:
         """ quickly roughly pre-calculate texture size of a multi-line string without rendering.
 
         :param text:            text string which can contain line feed characters.
         :param font_size:       the font size to pseudo-render the passed text; using the value of
                                 :attr:`~ae.gui_app.MainAppBase.font_size` as default if not passed.
-        :return:                roughly the size (width, height) to display the string passed into :paramref:`.text`.
-                                More exactly size would need to use internal render methods of Kivy, like e.g.
-                                :meth:`~kivy.uix.textinput.TextInput._get_text_width` and
+        :param padding:         optional padding in pixels for x and y coordinate (totals for left+right/top+bottom).
+        :return:                roughly the size (width, height) to display the string passed into
+                                :paramref:`~text_size_guess.text`. more exactly size would need to use internal render
+                                methods of Kivy, like e.g. :meth:`~kivy.uix.textinput.TextInput._get_text_width` and
                                 :meth:`~kivy.core.text.LabelBase.get_extents`.
         """
         if not font_size:
             font_size = self.font_size
 
-        char_width = font_size / 1.8
+        char_width = font_size / 1.77
         line_height = font_size * 1.2 if text else 0
         max_width = lines_height = 0.0
         for line in text.split("\n"):
@@ -1395,7 +1383,7 @@ class KivyMainApp(HelpAppBase):
                 max_width = line_width
             lines_height += line_height
 
-        return max_width, lines_height
+        return max_width + (padding[0] if text else 0.0), lines_height + (padding[1] if text else 0.0)
 
     def widget_children(self, wid: Any, only_visible: bool = False) -> List:
         """ determine the children of widget or its container (if exists) in z-order (top-most last).
